Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(494)

Unified Diff: ui/native_theme/native_theme_win.h

Issue 2716213002: ui: Fix cc/paint skia type mismatches (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/native_theme/native_theme_win.h
diff --git a/ui/native_theme/native_theme_win.h b/ui/native_theme/native_theme_win.h
index 759e278e54801f320a6fc0427ff6df1994b4137b..2f83a07b5e30bc03cb867307e60504bed5728f9f 100644
--- a/ui/native_theme/native_theme_win.h
+++ b/ui/native_theme/native_theme_win.h
@@ -127,10 +127,11 @@ class NATIVE_THEME_EXPORT NativeThemeWin : public NativeTheme,
// Update the locally cached set of system colors.
void UpdateSystemColors();
- // Painting functions that paint to SkCanvas.
- void PaintMenuSeparator(SkCanvas* canvas, const gfx::Rect& rect) const;
- void PaintMenuGutter(SkCanvas* canvas, const gfx::Rect& rect) const;
- void PaintMenuBackground(SkCanvas* canvas, const gfx::Rect& rect) const;
+ // Painting functions that paint to PaintCanvas.
+ void PaintMenuSeparator(cc::PaintCanvas* canvas, const gfx::Rect& rect) const;
+ void PaintMenuGutter(cc::PaintCanvas* canvas, const gfx::Rect& rect) const;
+ void PaintMenuBackground(cc::PaintCanvas* canvas,
+ const gfx::Rect& rect) const;
// Paint directly to canvas' HDC.
void PaintDirect(SkCanvas* destination_canvas,
@@ -143,7 +144,7 @@ class NATIVE_THEME_EXPORT NativeThemeWin : public NativeTheme,
// Create a temporary HDC, paint to that, clean up the alpha values in the
// temporary HDC, and then blit the result to canvas. This is to work around
// the fact that Windows XP and some classic themes give bogus alpha values.
- void PaintIndirect(SkCanvas* destination_canvas,
+ void PaintIndirect(cc::PaintCanvas* destination_canvas,
Part part,
State state,
const gfx::Rect& rect,

Powered by Google App Engine
This is Rietveld 408576698